@@ -88,7 +88,7 @@
     <message>
         <location filename="../mainwindow.ui" line="298"/>
         <source>Verbosity (less to more):</source>
-        <translation>Verbosidad (less a more)</translation>
+        <translation>Verbosidad (de menos a más)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="349"/>
@@ -98,17 +98,17 @@
     <message>
         <location filename="../mainwindow.ui" line="381"/>
         <source>Make the ext4 filesystem even if one exists</source>
-        <translation>Haga el sistema de ficheros de ext4 aunque existe</translation>
+        <translation>Crear el sistema de ficheros de ext4 aunque exista</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="388"/>
         <source>Save the original boot directory when updating a live-usb</source>
-        <translation>Guarda la carpeta original de inicio cuando actualizando un live-usb</translation>
+        <translation>Guarda la carpeta original de inicio cuando actualice un live-usb</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="395"/>
         <source>Use gpt partitioning instead of msdos</source>
-        <translation>Usa particionamiento gpt en vez de msdos</translation>
+        <translation>Usar particionamiento gpt en vez de msdos</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="398"/>
@@ -118,7 +118,7 @@
     <message>
         <location filename="../mainwindow.ui" line="405"/>
         <source>Update (only update an existing live-usb)</source>
-        <translation>Actualiza (solamente actualiza un liveUSB existente)</translation>
+        <translation>Actualizar (solamente actualiza un liveUSB existente)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="412"/>
@@ -128,7 +128,7 @@
     <message>
         <location filename="../mainwindow.ui" line="415"/>
         <source>Keep syslinux files</source>
-        <translation>Mantenga ficheros syslinux</translation>
+        <translation>Mantener ficheros syslinux</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="422"/>
@@ -154,7 +154,7 @@
         <location filename="../mainwindow.ui" line="465"/>
         <location filename="../mainwindow.cpp" line="424"/>
         <source>Show advanced options</source>
-        <translation>Muestra opciones avanzadas</translation>
+        <translation>Mostrar opciones avanzadas</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="484"/>
@@ -179,7 +179,7 @@
     <message>
         <location filename="../mainwindow.ui" line="526"/>
         <source>For distros other than antiX/MX use image mode (dd).</source>
-        <translation>Para distros no antiX/MX utiliza el modo imagen (dd).</translation>
+        <translation>Para distros no antiX/MX utilizar el modo imagen (dd).</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="574"/>
@@ -189,12 +189,12 @@
     <message>
         <location filename="../mainwindow.ui" line="609"/>
         <source>Percent of USB-device to use:</source>
-        <translation>Porciento del dispositivo USB a utilizar:</translation>
+        <translation>Porcentaje del dispositivo USB a utilizar:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="616"/>
         <source>Label ext partition:</source>
-        <translation>Rotula para partición ext:</translation>
+        <translation>Etiqueta para partición ext:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="664"/>
@@ -204,7 +204,7 @@
     <message>
         <location filename="../mainwindow.ui" line="667"/>
         <source>Dry run (no change to system)</source>
-        <translation>Modo simulación (ningun cambio al sistema)</translation>
+        <translation>Modo simulación (ningún cambio al sistema)</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="674"/>
@@ -219,7 +219,7 @@
     <message>
         <location filename="../mainwindow.ui" line="684"/>
         <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
-        <translation>Configurar para iniciar desde partición cifrado, se pregunta para frase de pase en el primer arranque</translation>
+        <translation>Configurar para iniciar desde una partición cifrada; preguntará la frase de paso en el primer arranque</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="687"/>
@@ -229,7 +229,7 @@
     <message>
         <location filename="../mainwindow.ui" line="694"/>
         <source>Clone running live system</source>
-        <translation>Un sistema clonada ejecutando en vivo</translation>
+        <translation>Clonar el sistema que se ejecuta en vivo</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="78"/>
@@ -241,7 +241,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="78"/>
         <source>Source and destination are on the same device, please select again.</source>
-        <translation>Fuente y destinación en el mismo dispositivo, seleccionar de nuevo.</translation>
+        <translation>La fuente y el destino están en el mismo dispositivo; seleccionar de nuevo.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="100"/>
@@ -250,12 +250,12 @@
 Please wait until the the process is completed</source>
         <translation>Escribiendo %1 con el comando &apos;dd&apos; hacia /dev/%2,
 
-Favor espere hasta que el proceso completa.</translation>
+Favor espere hasta que el proceso termine.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="244"/>
         <source>Success</source>
-        <translation>Exito</translation>
+        <translation>Éxito</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="244"/>
@@ -265,7 +265,7 @@ Favor espere hasta que el proceso completa.</translation>
     <message>
         <location filename="../mainwindow.cpp" line="246"/>
         <source>Error encountered in the LiveUSB creation process</source>
-        <translation>Encontro error en proceso de creación del LiveUSB</translation>
+        <translation>Se encontró un error en el proceso de creación del LiveUSB</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="292"/>
@@ -275,7 +275,7 @@ Favor espere hasta que el proceso completa.</translation>
     <message>
         <location filename="../mainwindow.cpp" line="292"/>
         <source>Please select a USB device to write to</source>
-        <translation>Favor seleccione dispositivo USB a donde escribir</translation>
+        <translation>Favor seleccione el dispositivo USB al cual escribir</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="295"/>
@@ -296,7 +296,7 @@ Favor espere hasta que el proceso completa.</translation>
     <message>
         <location filename="../mainwindow.cpp" line="336"/>
         <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
-        <translation>Programa para crear liveUSB desde un fichero ISO, otro liveUSB, liveCD/DVD, o un sistema actualmente ejecutando.</translation>
+        <translation>Programa para crear liveUSB desde un fichero ISO, otro liveUSB, liveCD/DVD, o un sistema actualmente en ejecución.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="338"/>
@@ -338,24 +338,24 @@ Favor espere hasta que el proceso completa.</translation>
     <message>
         <location filename="../mainwindow.cpp" line="409"/>
         <source>Could not find %1/antiX/linuxfs file</source>
-        <translation>No encontro %1/antiX/linuxfs fichero</translation>
+        <translation>No encontró el fichero %1/antiX/linuxfs</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="430"/>
         <source>Hide advanced options</source>
-        <translation>Esconde opciones avanzadas</translation>
+        <translation>Esconder opciones avanzadas</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="473"/>
         <location filename="../mainwindow.cpp" line="488"/>
         <source>Select Source</source>
-        <translation>Seleccione Fuente</translation>
+        <translation>Seleccionar Fuente</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="477"/>
         <location filename="../mainwindow.cpp" line="494"/>
         <source>Select ISO file</source>
-        <translation>Seleccione fichero ISO</translation>
+        <translation>Seleccionar fichero ISO</translation>
     </message>
 </context>
 <context>
